==> zio-aws-lightsail_2.12-5.17.172.1-sources.jar: zio/aws/lightsail/model/CreateContainerServiceRequest.scala <==
package zio.aws.lightsail.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  ContainerServiceScale,
  ContainerServiceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateContainerServiceRequest(
    serviceName: ContainerServiceName,
    power: zio.aws.lightsail.model.ContainerServicePowerName,
    scale: ContainerServiceScale,
    tags: Optional[Iterable[zio.aws.lightsail.model.Tag]] = Optional.Absent,
    publicDomainNames: Optional[Map[String, Iterable[String]]] =
      Optional.Absent,
    deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest = {
    import CreateContainerServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
      .builder()
      .serviceName(ContainerServiceName.unwrap(serviceName): java.lang.String)
      .power(power.unwrap)
      .scale(ContainerServiceScale.unwrap(scale): Integer)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        publicDomainNames.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.publicDomainNames)
      .optionallyWith(deployment.map(value => value.buildAwsValue()))(
        _.deployment
      )
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly =
    zio.aws.lightsail.model.CreateContainerServiceRequest.wrap(buildAwsValue())
}
object CreateContainerServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.CreateContainerServiceRequest =
      zio.aws.lightsail.model.CreateContainerServiceRequest(
        serviceName,
        power,
        scale,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        publicDomainNames.map(value => value),
        deployment.map(value => value.asEditable)
      )
    def serviceName: ContainerServiceName
    def power: zio.aws.lightsail.model.ContainerServicePowerName
    def scale: ContainerServiceScale
    def tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]]
    def publicDomainNames: Optional[Map[String, List[String]]]
    def deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ]
    def getServiceName: ZIO[Any, Nothing, ContainerServiceName] =
      ZIO.succeed(serviceName)
    def getPower
        : ZIO[Any, Nothing, zio.aws.lightsail.model.ContainerServicePowerName] =
      ZIO.succeed(power)
    def getScale: ZIO[Any, Nothing, ContainerServiceScale] = ZIO.succeed(scale)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getPublicDomainNames: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("publicDomainNames", publicDomainNames)
    def getDeployment: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ] = AwsError.unwrapOptionField("deployment", deployment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ) extends zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly {
    override val serviceName: ContainerServiceName =
      zio.aws.lightsail.model.primitives
        .ContainerServiceName(impl.serviceName())
    override val power: zio.aws.lightsail.model.ContainerServicePowerName =
      zio.aws.lightsail.model.ContainerServicePowerName.wrap(impl.power())
    override val scale: ContainerServiceScale =
      zio.aws.lightsail.model.primitives.ContainerServiceScale(impl.scale())
    override val tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lightsail.model.Tag.wrap(item)
          }.toList
        )
    override val publicDomainNames: Optional[Map[String, List[String]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.publicDomainNames())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> value.asScala.map { item =>
                item: String
              }.toList
            })
            .toMap
        )
    override val deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.deployment())
      .map(value =>
        zio.aws.lightsail.model.ContainerServiceDeploymentRequest.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ): zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/CreateContainerServiceRequest.scala <==
package zio.aws.lightsail.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  ContainerServiceScale,
  ContainerServiceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateContainerServiceRequest(
    serviceName: ContainerServiceName,
    power: zio.aws.lightsail.model.ContainerServicePowerName,
    scale: ContainerServiceScale,
    tags: Optional[Iterable[zio.aws.lightsail.model.Tag]] = Optional.Absent,
    publicDomainNames: Optional[Map[String, Iterable[String]]] =
      Optional.Absent,
    deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest
    ] = Optional.Absent,
    privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest = {
    import CreateContainerServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
      .builder()
      .serviceName(ContainerServiceName.unwrap(serviceName): java.lang.String)
      .power(power.unwrap)
      .scale(ContainerServiceScale.unwrap(scale): Integer)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        publicDomainNames.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.publicDomainNames)
      .optionallyWith(deployment.map(value => value.buildAwsValue()))(
        _.deployment
      )
      .optionallyWith(
        privateRegistryAccess.map(value => value.buildAwsValue())
      )(_.privateRegistryAccess)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly =
    zio.aws.lightsail.model.CreateContainerServiceRequest.wrap(buildAwsValue())
}
object CreateContainerServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.CreateContainerServiceRequest =
      zio.aws.lightsail.model.CreateContainerServiceRequest(
        serviceName,
        power,
        scale,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        publicDomainNames.map(value => value),
        deployment.map(value => value.asEditable),
        privateRegistryAccess.map(value => value.asEditable)
      )
    def serviceName: ContainerServiceName
    def power: zio.aws.lightsail.model.ContainerServicePowerName
    def scale: ContainerServiceScale
    def tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]]
    def publicDomainNames: Optional[Map[String, List[String]]]
    def deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ]
    def privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ]
    def getServiceName: ZIO[Any, Nothing, ContainerServiceName] =
      ZIO.succeed(serviceName)
    def getPower
        : ZIO[Any, Nothing, zio.aws.lightsail.model.ContainerServicePowerName] =
      ZIO.succeed(power)
    def getScale: ZIO[Any, Nothing, ContainerServiceScale] = ZIO.succeed(scale)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getPublicDomainNames: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("publicDomainNames", publicDomainNames)
    def getDeployment: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ] = AwsError.unwrapOptionField("deployment", deployment)
    def getPrivateRegistryAccess: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ] =
      AwsError.unwrapOptionField("privateRegistryAccess", privateRegistryAccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ) extends zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly {
    override val serviceName: ContainerServiceName =
      zio.aws.lightsail.model.primitives
        .ContainerServiceName(impl.serviceName())
    override val power: zio.aws.lightsail.model.ContainerServicePowerName =
      zio.aws.lightsail.model.ContainerServicePowerName.wrap(impl.power())
    override val scale: ContainerServiceScale =
      zio.aws.lightsail.model.primitives.ContainerServiceScale(impl.scale())
    override val tags: Optional[List[zio.aws.lightsail.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lightsail.model.Tag.wrap(item)
          }.toList
        )
    override val publicDomainNames: Optional[Map[String, List[String]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.publicDomainNames())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> value.asScala.map { item =>
                item: String
              }.toList
            })
            .toMap
        )
    override val deployment: Optional[
      zio.aws.lightsail.model.ContainerServiceDeploymentRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.deployment())
      .map(value =>
        zio.aws.lightsail.model.ContainerServiceDeploymentRequest.wrap(value)
      )
    override val privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.privateRegistryAccess())
      .map(value =>
        zio.aws.lightsail.model.PrivateRegistryAccessRequest.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.CreateContainerServiceRequest
  ): zio.aws.lightsail.model.CreateContainerServiceRequest.ReadOnly =
    new Wrapper(impl)
}
